/**
 * Corresponds with the box interface returned by methods such as `getBBox`.
 */
interface Box {
    /**
     * The minimum X coordinate of the box.
     */
    x: number;
    /**
     * The minimum Y coordinate of the box.
     */
    y: number;
    width: number;
    height: number;
}
/**
 * Represents an SVG element that can be added to an SVG document (or an overlaid SVG document)
 * to highlight a specified box (such as the bounding box of another SVG element).
 *
 * Currently has the appearance of a blue and aqua dashed line drawn around a specified box.
 *
 * The underlying DOM nodes that make up a box trace are not meant to be directly edited by outside code
 * but rather only edited through the interface provided by this class.
 */
export declare class BoxTrace {
    /**
     * The actual DOM node that is the box trace.
     *
     * Contains all the elements of the box trace.
     */
    private domNode;
    private blueDashing;
    private aquaDashing;
    constructor();
    /**
     * Appends the box trace to the given container node.
     */
    appendTo(container: Node): void;
    /**
     * Removes the box trace from any container node that it is in.
     *
     * Has no effect if the box trace has no parent container node.
     */
    remove(): void;
    /**
     * Repositions and resizes the box trace so that it traces the specified box.
     */
    trace(box: Box): void;
    /**
     * Sets the thickness of the box trace (in pixels).
     */
    setThickness(thickness: number): void;
    setOpacity(opacity: number): void;
}
export {};
//# sourceMappingURL=BoxTrace.d.ts.map